<?php
/*
Plugin Name: Linkwash
Plugin URI: http://www.linkwash.de/
Description: Linkwash wandelt die Links auf Ihrer Website automatisch und in Echtzeit in Affiliate-Links um. Mit nur einer Anmeldung können Sie so Tausende von Affiliate-Programmen bewerben und effizient Umsätze generieren.
Version: 0.5.0
Author: Linkwash
Author URI: http://www.linkwash.de/
*/
class LinkwashPlugin
{
    private $_linkwashId = null;
    
    /**
     * Initially read the current linkwashId
     */
    public function __construct()
    {
        $this->_linkwashId = get_option('linkwashId');
        if ($this->_linkwashId === false) {
            //Add the option
            add_option('linkwashId', '');
        }
    }
    
    /**
     * Called on activation of plugin
     */
    public function activate()
    {
        //Add empty linkwashId Option
        add_option('linkwashId', '');
    }
    
    /**
     * Called on deactivation of plugin
     */
    public function deactivate()
    {
        //Remove the formerly added linkwashId Option
        delete_option('linkwashId');
    }
    
    /**
     * Adds the java-script to the footer of wordpress
     */
    public function linkwashFooter()
    {
        if ($this->_linkwashId != '') {
            include 'script.phtml';
        }
    }
    
    /**
     * Adds the settings link to the plugin overview
     */
    public function addSettingsLink($links, $file)
    {
        static $thisPlugin;
        if (!$thisPlugin) {
            $thisPlugin = plugin_basename(dirname(__FILE__).'/linkwash.php');
        }
        
        if ($file == $thisPlugin) {
            $settingsLink = '<a href="plugins.php?page=linkwash-key-config">'
                            .__("Einstellungen").'</a>';
            $links[] = $settingsLink;
        }
        return $links;
    }
    
    /**
     * Adds the configuration submenu item to plugin submenu
     */
    public function addLinkwashConfigMenu()
    {
        if (function_exists('add_submenu_page')) {
            add_submenu_page(
                'plugins.php',
                __('Linkwash Konfiguration'),
                __('Linkwash Konfiguration'),
                'manage_options',
                'linkwash-key-config',
                array(&$this, 'linkwashConfig')
            );
        }
    }
    
    /**
     * Get the warning message that linkwashId is not yet set
     */
    public function getWarning()
    {
        echo '<div class="updated fade"><p><strong>'
             .__('Linkwash ist fast bereit.').'</strong> '
             .sprintf(
                 __(
                     'Sie müssen <a href="%1$s">ihre Linkwash-ID eingeben</a>'
                     .', damit es funktioniert.'
                 ),
                 'plugins.php?page=linkwash-key-config'
             ).'</p></div>';
    }
    
    /**
     * If linkwashId is not set this calls getWarning() to display a warning 
     */
    public function adminWarnings()
    {
        if ($this->_linkwashId == '') {
            add_action('admin_notices', array(&$this, 'getWarning'));
        }
        return;
    }
    
    /**
     * Does the plugin configuration, i.e. Setting the linkwashId
     */
    public function linkwashConfig()
    {
        $this->error = '';
        $this->info = '';
        $this->success = '';
        
        if (isset($_POST['linkwashId']) &&
                  $_POST['linkwashId'] == ''
        ) {
            $this->info = _('Ihre Linkwash-ID wurde entfernt');
            update_option('linkwashId', $_POST['linkwashId']);
        } elseif (isset($_POST['linkwashId']) &&
            !is_numeric($_POST['linkwashId'])
        ) {
            $this->error = _('Die Linkwash-ID is nicht gültig');
        } elseif (isset($_POST['linkwashId'])) {
            $this->success = _('Ihre Linkwash-ID wurde gespeichert');
            update_option('linkwashId', $_POST['linkwashId']);
        }
        if (isset($_POST['linkwashId'])) {
            $this->_linkwashId = $_POST['linkwashId'];
        }
        include 'config.phtml';
    }
}

$lwPlugin = new LinkwashPlugin();

add_action('wp_footer', array(&$lwPlugin, 'linkwashFooter'));
add_action('admin_menu', array(&$lwPlugin, 'addLinkwashConfigMenu'));
add_filter('plugin_action_links', array(&$lwPlugin, 'addSettingsLink'), 10, 2);

register_activation_hook(__FILE__, array(&$lwPlugin, 'activate'));
register_deactivation_hook(__FILE__, array(&$lwPlugin, 'deactivate'));

$lwPlugin->adminWarnings();